ChartStyle class

Constructors

ChartStyle()

Properties

bottomPadding ↔ double
getter/setter pair
candleLineWidth ↔ double
getter/setter pair
candleWidth ↔ double
candle width
getter/setter pair
childPadding ↔ double
getter/setter pair
dateTimeFormat ↔ List<String>?
customize the time below
getter/setter pair
gridColumns ↔ int
getter/setter pair
gridRows ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hCrossWidth ↔ double
getter/setter pair
isFocusCloseText ↔ bool
getter/setter pair
isLongFocus ↔ bool
getter/setter pair
isNotPoint ↔ bool
getter/setter pair
isShowBottomMa ↔ bool
getter/setter pair
isShowEma ↔ bool
getter/setter pair
isShowHighOrLowPoint ↔ bool
getter/setter pair
isShowLeftTopicPoint ↔ bool
getter/setter pair
isShowStrategyTypeBottom ↔ bool
getter/setter pair
isShowStrategyTypeBottomForMaxVol ↔ bool
getter/setter pair
isShowStrategyTypeTop ↔ bool
getter/setter pair
leftPadding ↔ double
getter/setter pair
macdWidth ↔ double
macd column width
getter/setter pair
nowPriceLineLength ↔ double
(line length - space line - thickness) of the current price
getter/setter pair
nowPriceLineSpan ↔ double
getter/setter pair
nowPriceLineWidth ↔ double
getter/setter pair
pointWidth ↔ double
point-to-point distance
getter/setter pair
rightPadding ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showMAVolume ↔ bool
getter/setter pair
sizeText ↔ double
getter/setter pair
topPadding ↔ double
getter/setter pair
vCrossWidth ↔ double
vertical-horizontal cross line width
getter/setter pair
volisDouble ↔ bool
vol column is double
getter/setter pair
volWidth ↔ double
vol column width
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited