KChartWidgetState class

Inheritance
Mixed-in types

Constructors

KChartWidgetState()

Properties

aniX ↔ Animation<double>?
getter/setter pair
changeinXposition ↔ double?
getter/setter pair
changeinYposition ↔ double?
getter/setter pair
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
enableCordRecord ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
infos ↔ List<String>
getter/setter pair
isDrag ↔ bool
getter/setter pair
isLongPress ↔ bool
getter/setter pair
isOnTap ↔ bool
getter/setter pair
isScale ↔ bool
getter/setter pair
lines ↔ List<TrendLine>
getter/setter pair
mHeight ↔ double
getter/setter pair
mInfoWindowStream → StreamController<InfoWindowEntity?>
final
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
mScaleX ↔ double
getter/setter pair
mScrollX ↔ double
getter/setter pair
mSelectX ↔ double
getter/setter pair
mSelectY ↔ double
getter/setter pair
mWidth ↔ double
getter/setter pair
pointerCount ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
waitingForOtherPairofCords ↔ bool
getter/setter pair
widget → KChartWidget
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createTicker(TickerCallback onTick) → Ticker
Creates a ticker with the given callback.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
override
didUpdateWidget(covariant KChartWidget oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
getMinScrollX() → double
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChanged() → void
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited