secondaryStateLi property
A set of enums indicating the types of secondary indicators to display (e.g., MACD, KDJ).
Implementation
Set<SecondaryState> secondaryStateLi;
A set of enums indicating the types of secondary indicators to display (e.g., MACD, KDJ).
Set<SecondaryState> secondaryStateLi;